@@ -160,7 +160,7 @@ void g_mozilla_connectivity_handle (GMozillaEngine *self, gint event)
     case OSSO_CON_IC_CONNECTING:
         ULOG_INFO_F("OSSO_CON_IC_CONNECTING, arg:%p, global:%p\n", self, webglobal);
         connected = FALSE;
-        if (self->progress_bar_state != 0 && self->user_iteraction_happens)
+        if (self->progress_bar_state != 0 && self->user_iteraction_happens && self->waiting_connection)
           g_signal_emit_by_name(G_OBJECT(self), "start_loading" , 0, self->will_open_location);
         self->progress_bar_state = 0;
         return;
